@@ -631,46 +631,24 @@ purple_network_is_available(void)
 }
 
 #ifdef HAVE_ICD
-static gboolean
-wait_for_accounts_to_disconnect_timeout_cb(gboolean *keep_waiting)
-{
-	(*keep_waiting) = FALSE;
-	return FALSE;
-}
-
 static void
 icd_connect_status_notify(GObject *conn_mon, GParamSpec *pspec, gpointer null)
 {
 	ICDConnMonStatus status;
-	PurpleConnectionUiOps *ui_ops = purple_connections_get_ui_ops();
+	PurpleConnectionUiOps *ui_ops = NULL;
+
+	/* Don't want to re-enter this function before we exit it */
+	g_object_freeze_notify(conn_mon);
+
+	ui_ops = purple_connections_get_ui_ops();
 
 	purple_signal_emit(purple_network_get_handle(), "network-configuration-changed", NULL);
 
 	g_object_get(conn_mon, "connect-status", &status, NULL);
 
 	if (ICD_CONN_MON_DISCONNECTED == status || ICD_CONN_MON_RECONNECTED == status) {
-		GList *llItr = NULL;
-		gboolean keep_waiting = TRUE;
-		guint timeout_id = 0;
-
 		if (ui_ops && ui_ops->network_disconnected)
 			ui_ops->network_disconnected();
-
-		/* Wait for all accounts to disconnect. Freeze notifications that may happen while waiting for disconnects */
-		g_object_freeze_notify(conn_mon);
-		timeout_id = g_timeout_add(10000, (GSourceFunc)wait_for_accounts_to_disconnect_timeout_cb, &keep_waiting);
-		for (llItr = purple_accounts_get_all_active() ; llItr != NULL && keep_waiting ; llItr = llItr->next) {
-			if (!purple_account_is_disconnected ((PurpleAccount *)(llItr->data))) {
-				g_main_context_iteration (NULL, TRUE) ;
-				/* Accounts may have changed */
-				llItr = purple_accounts_get_all_active () ;
-			}
-		}
-		if (keep_waiting && timeout_id)
-			g_source_remove(timeout_id);
-		timeout_id = 0;
-		keep_waiting = FALSE;
-		g_object_thaw_notify(conn_mon);
 	}
 
 	if ((ICD_CONN_MON_CONNECTED == status || ICD_CONN_MON_RECONNECTED == status)) {
@@ -678,6 +656,8 @@ icd_connect_status_notify(GObject *conn_mon, GParamSpec *pspec, gpointer null)
 		if (ui_ops && ui_ops->network_connected)
 			ui_ops->network_connected();
 	}
+
+	g_object_thaw_notify(conn_mon);
 }
 #endif /* HAVE_ICD */
 
