@@ -704,8 +704,7 @@ request_theme_file_name_cb(gpointer data, char *theme_file_name)
 static void
 add_theme_button_clicked_cb(GtkWidget *widget, gpointer null)
 {
-	purple_request_file_with_hint(NULL, _("Install Theme"), NULL, FALSE,
-	    (GCallback)request_theme_file_name_cb, NULL, NULL, NULL, NULL, PURPLE_REQUEST_UI_HINT_PREFSMGR, NULL) ;
+	purple_request_file(NULL, _("Install Theme"), NULL, FALSE, (GCallback)request_theme_file_name_cb, NULL, NULL, NULL, NULL, NULL) ;
 }
 
 static void
@@ -1424,6 +1423,10 @@ network_page()
 		gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
 		if (gtk_entry_get_invisible_char(GTK_ENTRY(entry)) == '*')
 			gtk_entry_set_invisible_char(GTK_ENTRY(entry), PIDGIN_INVISIBLE_CHAR);
+#ifdef USE_HILDON
+		hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry),
+			hildon_gtk_entry_get_input_mode(GTK_ENTRY(entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 		g_signal_connect(G_OBJECT(entry), "changed",
 				 G_CALLBACK(proxy_print_option), (void *)PROXYPASS);
 
@@ -1793,9 +1796,9 @@ static void select_sound(GtkWidget *button, gpointer being_NULL_is_fun)
 	if (*filename == '\0')
 		filename = NULL;
 
-	purple_request_file_with_hint(prefs, _("Sound Selection"), filename, FALSE,
+	purple_request_file(prefs, _("Sound Selection"), filename, FALSE,
 					  G_CALLBACK(sound_chosen_cb), NULL,
-					  NULL, NULL, NULL, PURPLE_REQUEST_UI_HINT_PREFSMGR,
+					  NULL, NULL, NULL,
 					  GINT_TO_POINTER(sound_row_sel));
 }
 
