@@ -481,6 +481,10 @@ pidgin_request_input(const char *title, const char *primary,
 				gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
 				if (gtk_entry_get_invisible_char(GTK_ENTRY(entry)) == '*')
 					gtk_entry_set_invisible_char(GTK_ENTRY(entry), PIDGIN_INVISIBLE_CHAR);
+#ifdef USE_HILDON
+				hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry),
+					hildon_gtk_entry_get_input_mode(GTK_ENTRY(entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 			}
 		}
 		gtk_widget_show_all(vbox);
@@ -836,6 +840,10 @@ create_string_field(PurpleRequestField *field)
 			gtk_entry_set_visibility(GTK_ENTRY(widget), FALSE);
 			if (gtk_entry_get_invisible_char(GTK_ENTRY(widget)) == '*')
 				gtk_entry_set_invisible_char(GTK_ENTRY(widget),	PIDGIN_INVISIBLE_CHAR);
+#ifdef USE_HILDON
+			hildon_gtk_entry_set_input_mode(GTK_ENTRY(widget),
+				hildon_gtk_entry_get_input_mode(GTK_ENTRY(widget)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 		}
 
 		gtk_editable_set_editable(GTK_EDITABLE(widget),
